/*
 * Mirai. Copyright (C) 2024 Vyn
 * This file is licensed under version 3 of the GNU General Public License (GPL-3.0-only)
 * The license can be found in the LICENSE file or at https://www.gnu.org/licenses/gpl-3.0.txt
 */

#include "Event.h"
#include "Task.h"
#include <string>

namespace mirai
{

int Event::id() const
{
	return _data.id;
}

int Event::source_id() const
{
	return _provider->id;
}

std::string Event::title() const
{
	return _data.title;
}

Date Event::date() const
{
	return _data.date;
}

Time Event::starts_at() const
{
	return _data.starts_at;
}

Time Event::ends_at() const
{
	return _data.ends_at;
}

void Event::set_title(const std::string &newTitle)
{
	_provider->update_event(id(), {.title = newTitle});
}

void Event::set_date(const Date &date)
{
	_provider->update_event(id(), {.date = date});
}

void Event::set_start_time(const Time &time)
{
	_provider->update_event(id(), {.starts_at = time});
}

void Event::set_end_time(const Time &time)
{
	_provider->update_event(id(), {.ends_at = time});
}
} // namespace mirai
